==> polls-v1.4.1.zip: polls/messages/ja/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>注意：</strong> 結果はアンケートが終了するまで表示されません。',
    'Access denied!' => 'アクセスが拒否されました！',
    'Add answer...' => '回答を追加...',
    'Again? ;Weary;' => 'また？ ;疲れた;',
    'Allows the user to create polls' => '投票を作成できるようにします',
    'Allows to start polls.' => '投票形式のアンケートを開始できます。',
    'Anonymous' => '匿名',
    'Anonymous Votes?' => '匿名の投票？',
    'Anonymous poll!' => '匿名アンケートです！',
    'Answers' => '回答',
    'At least one answer is required' => '1つ以上の回答が必要です',
    'Cancel' => 'キャンセル',
    'Close Poll' => 'アンケートを終了',
    'Closed' => '終了',
    'Club A Steakhouse' => 'クラブAステーキハウス',
    'Could not load poll!' => 'アンケートを読み込めませんでした！',
    'Create poll' => '投票を作成する',
    'Description' => '説明',
    'Display answers in random order?' => '回答をランダムな順序で表示する？',
    'Edit answer (empty answers will be removed)...' => '回答を編集（空欄の回答は削除されます）...',
    'Edit your poll question...' => '質問を編集...',
    'Hide results until poll is closed?' => 'アンケートを終了するまで結果を表示しない？',
    'Invalid answer!' => '無効な回答です！',
    'Location of the next meeting' => '次の会議の場所',
    'Multiple answers per user' => 'ユーザーごとの複数回答',
    'Pisillo Italian Panini' => 'ピシーロイタリアンパニーニ',
    'Please specify at least {min} answers!' => '少なくとも {min} の回答を指定してください！',
    'Poll' => 'アンケート',
    'Polls' => 'アンケート',
    'Question' => '質問',
    'Reopen Poll' => 'アンケートを再開',
    'Reset my vote' => '私の投票をリセット',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => '現在、次のミートアップの計画段階にあります。どこに行きたいですか？',
    'Save' => '保存',
    'To Daniel' => 'ダニエルへ',
    'Users voted for: <strong>{answer}</strong>' => '<strong>{answer}</strong> に投票したユーザー',
    'Vote' => '投票',
    'Voting for multiple answers is disabled!' => '複数回答への投票は無効になっています！',
    'Whenever someone participates in a poll.' => '誰かが投票に参加するときはいつでも。',
    'Why don\'t we go to Bemelmans Bar?' => 'ベメルマンズバーに行ってみませんか？',
    'You have insufficient permissions to perform that operation!' => 'あなたにはその操作を実行するための権限がありません！',
    'and {count} more vote for this.' => '他 {count} 人が投票',
    'votes' => '票',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} さんが回答しました。{question}',
    'Poll content ID' => '',
];

==> polls-v1.4.2.zip: polls/messages/ja/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>注意：</strong> 結果はアンケートが終了するまで表示されません。',
    'Access denied!' => 'アクセスが拒否されました！',
    'Add answer...' => '回答を追加...',
    'Again? :weary:' => 'また？ ;疲れた;',
    'Allows the user to create polls' => '投票を作成できるようにします',
    'Allows to start polls.' => '投票形式のアンケートを開始できます。',
    'Anonymous' => '匿名',
    'Anonymous Votes?' => '匿名の投票？',
    'Anonymous poll!' => '匿名アンケートです！',
    'Answers' => '回答',
    'At least one answer is required' => '1つ以上の回答が必要です',
    'Cancel' => 'キャンセル',
    'Close Poll' => 'アンケートを終了',
    'Closed' => '終了',
    'Club A Steakhouse' => 'クラブAステーキハウス',
    'Could not load poll!' => 'アンケートを読み込めませんでした！',
    'Create poll' => '投票を作成する',
    'Description' => '説明',
    'Display answers in random order?' => '回答をランダムな順序で表示する？',
    'Edit answer (empty answers will be removed)...' => '回答を編集（空欄の回答は削除されます）...',
    'Edit your poll question...' => '質問を編集...',
    'Hide results until poll is closed?' => 'アンケートを終了するまで結果を表示しない？',
    'Invalid answer!' => '無効な回答です！',
    'Location of the next meeting' => '次の会議の場所',
    'Multiple answers per user' => 'ユーザーごとの複数回答',
    'Pisillo Italian Panini' => 'ピシーロイタリアンパニーニ',
    'Please specify at least {min} answers!' => '少なくとも {min} の回答を指定してください！',
    'Poll' => 'アンケート',
    'Polls' => 'アンケート',
    'Question' => '質問',
    'Reopen Poll' => 'アンケートを再開',
    'Reset my vote' => '私の投票をリセット',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => '現在、次のミートアップの計画段階にあります。どこに行きたいですか？',
    'Save' => '保存',
    'To Daniel' => 'ダニエルへ',
    'Users voted for: <strong>{answer}</strong>' => '<strong>{answer}</strong> に投票したユーザー',
    'Vote' => '投票',
    'Voting for multiple answers is disabled!' => '複数回答への投票は無効になっています！',
    'Whenever someone participates in a poll.' => '誰かが投票に参加するときはいつでも。',
    'Why don\'t we go to Bemelmans Bar?' => 'ベメルマンズバーに行ってみませんか？',
    'You have insufficient permissions to perform that operation!' => 'あなたにはその操作を実行するための権限がありません！',
    'and {count} more vote for this.' => '他 {count} 人が投票',
    'votes' => '票',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} さんが回答しました。{question}',
    'Poll content ID' => '',
];
